"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sentry_1 = __importDefault(require("../../services/sentry"));
const utils_1 = require("../../utils");
exports.default = (webHookOptions) => {
    return async (req, res) => {
        if (!(0, utils_1.verifySignature)(req, webHookOptions.secret)) {
            return res.sendStatus(401);
        }
        res.status(200);
        // Parse the JSON body fields off of the request
        const { action, data, installation, actor } = req.body;
        const { uuid } = installation || {};
        // Identify the resource triggering the webhook in Sentry
        const resource = req.header('sentry-hook-resource');
        if (!action || !data || !uuid || !resource) {
            return res.sendStatus(400);
        }
        const sentryService = req.scope.resolve(sentry_1.default.RESOLVE_KEY);
        const dataToEmit = {
            actor,
            action,
            data,
            installation,
        };
        // Handle webhooks related to issues
        if (webHookOptions.emitOnIssue && resource === 'issue') {
            await sentryService.handleIssues(dataToEmit);
            res.status(200);
        }
        // Handle webhooks related to errors
        if (webHookOptions.emitOnError && resource === 'error') {
            await sentryService.handleErrors(dataToEmit);
            res.status(200);
        }
        // Handle webhooks related to comments
        if (webHookOptions.emitOnComment && resource === 'comment') {
            await sentryService.handleComments(dataToEmit);
            res.status(200);
        }
        // Handle webhooks related to alerts
        if (webHookOptions.emitOnEventOrMetricAlert && (resource === 'event_alert' || resource === 'metric_alert')) {
            await sentryService.handleAlerts(dataToEmit);
            res.status(200);
        }
        // Handle uninstallation webhook
        if (webHookOptions.emitOnInstallOrDeleted && resource === 'installation' && action === 'deleted') {
            await sentryService.handleInstallation(dataToEmit);
            res.status(200);
        }
        res.send();
    };
};
//# sourceMappingURL=sentry-web-hook.js.map