"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = __importStar(require("express"));
const cors_1 = __importDefault(require("cors"));
const Sentry = __importStar(require("@sentry/node"));
const Tracing = __importStar(require("@sentry/tracing"));
const authenticate_1 = __importDefault(require("@medusajs/medusa/dist/api/middlewares/authenticate"));
const await_middleware_1 = __importDefault(require("@medusajs/medusa/dist/api/middlewares/await-middleware"));
const medusa_core_utils_1 = require("medusa-core-utils");
const sentry_transaction_1 = __importDefault(require("./handlers/sentry-transaction"));
const sentry_transaction_events_1 = __importDefault(require("./handlers/sentry-transaction-events"));
const sentry_transactions_stats_1 = __importDefault(require("./handlers/sentry-transactions-stats"));
const sentry_web_hook_1 = __importDefault(require("./handlers/sentry-web-hook"));
function default_1(rootDirectory, pluginOptions) {
    const router = (0, express_1.Router)();
    const { integrations, requestHandlerOptions = {}, enableTracing = true, enableRequestHandler = true, webHookOptions, apiToken } = pluginOptions, options = __rest(pluginOptions, ["integrations", "requestHandlerOptions", "enableTracing", "enableRequestHandler", "webHookOptions", "apiToken"]);
    Sentry.init(Object.assign(Object.assign({}, options), { integrations: Array.isArray(integrations) ? integrations : integrations(router, Sentry, Tracing) }));
    if (enableRequestHandler) {
        // RequestHandler creates a separate execution context using domains, so that every
        // transaction/span/breadcrumb is attached to its own Hub instance
        router.use(Sentry.Handlers.requestHandler(requestHandlerOptions));
    }
    if (enableTracing) {
        // TracingHandler creates a trace for every incoming request
        router.use(Sentry.Handlers.tracingHandler());
    }
    attachSentryErrorHandler();
    if (webHookOptions) {
        attachSentryWebHook(router, webHookOptions);
    }
    if (apiToken) {
        attachAdminEndPoints(router, rootDirectory, pluginOptions);
    }
    return router;
}
exports.default = default_1;
/**
 * Attach the sentry error handler in the medusa core
 */
function attachSentryErrorHandler() {
    /* eslint-disable @typescript-eslint/no-var-requires */
    const medusaErrorHandler = require('@medusajs/medusa/dist/api/middlewares/error-handler');
    const originalMedusaErrorHandler = medusaErrorHandler.default;
    medusaErrorHandler.default = () => {
        return (err, req, res, next) => {
            Sentry.Handlers.errorHandler({
                shouldHandleError: () => true,
            })(err, req, res, () => void 0);
            originalMedusaErrorHandler()(err, req, res, next);
        };
    };
}
/**
 * Attach sentry web hook
 * @param router
 * @param webHookOptions
 */
function attachSentryWebHook(router, webHookOptions) {
    router.post('/admin' + webHookOptions.path, express_1.default.json(), express_1.default.urlencoded({ extended: true }), (0, sentry_web_hook_1.default)(webHookOptions));
}
/**
 * Attach specific sentry end point to fetch data under the admin domain
 * @param router
 * @param rootDirectory
 * @param pluginOptions
 */
function attachAdminEndPoints(router, rootDirectory, pluginOptions) {
    const { apiToken } = pluginOptions;
    const { configModule } = (0, medusa_core_utils_1.getConfigFile)(rootDirectory, 'medusa-config');
    const { projectConfig } = configModule;
    const corsOptions = {
        origin: projectConfig.admin_cors.split(','),
        credentials: true,
    };
    router.use('/admin/sentry-transactions', (0, cors_1.default)(corsOptions));
    router.get('/admin/sentry-transactions', (0, authenticate_1.default)(), (0, await_middleware_1.default)((0, sentry_transaction_1.default)(apiToken)));
    router.use('/admin/sentry-transactions-stats', (0, cors_1.default)(corsOptions));
    router.get('/admin/sentry-transactions-stats', (0, authenticate_1.default)(), (0, await_middleware_1.default)((0, sentry_transactions_stats_1.default)(apiToken)));
    router.use('/admin/sentry-transaction-events', (0, cors_1.default)(corsOptions));
    router.get('/admin/sentry-transaction-events', (0, authenticate_1.default)(), (0, await_middleware_1.default)((0, sentry_transaction_events_1.default)(apiToken)));
}
//# sourceMappingURL=index.js.map